import { Plugin } from 'rollup';
export declare type EnvVarReplacements = Record<string, string | number | true>;
export declare type DevScript = {
    cmd: string;
    watch: string | undefined;
};
export declare type DevScripts = {
    [id: string]: DevScript;
};
export interface SnowpackConfig {
    source: 'local' | 'pika';
    extends?: string;
    webDependencies?: {
        [packageName: string]: string;
    };
    entrypoints?: string[];
    dedupe?: string[];
    namedExports?: {
        [filepath: string]: string[];
    };
    dev: {
        out: string;
        src: string;
        dist: string;
        bundle: boolean;
        fallback: string;
    };
    scripts: DevScripts;
    installOptions: {
        babel?: boolean;
        clean: boolean;
        hash: boolean;
        dest: string;
        exclude: string[];
        externalPackage: string[];
        include?: string;
        nomodule?: string;
        nomoduleOutput: string;
        optimize: boolean;
        env?: EnvVarReplacements;
        installTypes: boolean;
        remotePackage?: string[];
        remoteUrl: string;
        sourceMap?: boolean | 'inline';
        stat: boolean;
        strict: boolean;
    };
    rollup: {
        plugins: Plugin[];
    };
}
export interface CLIFlags extends Omit<Partial<SnowpackConfig['installOptions']>, 'env'> {
    help?: boolean;
    version?: boolean;
    reload?: boolean;
    source?: SnowpackConfig['source'];
    config?: string;
    env?: string[];
}
export default function loadConfig(flags: CLIFlags, pkgManifest: any): {
    config: SnowpackConfig;
    errors: string[];
};
